==> haskell-base-orphans-0.8-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-base-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-orphans
version: 0.8
id: base-orphans-0.8-IMe9IACIp8aFSEynTCteC2
key: base-orphans-0.8-IMe9IACIp8aFSEynTCteC2
license: MIT
copyright: (c) 2012-2017 Simon Hengel,
           (c) 2014-2017 João Cristóvão,
           (c) 2015-2017 Ryan Scott
maintainer: Simon Hengel <sol@typeful.net>,
            João Cristóvão <jmacristovao@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
author: Simon Hengel <sol@typeful.net>,
        João Cristóvão <jmacristovao@gmail.com>,
        Ryan Scott <ryan.gl.scott@gmail.com>
homepage: https://github.com/haskell-compat/base-orphans#readme
synopsis: Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in later versions of @base@ to a wider (older) range of compilers. @base-orphans@ does not export anything except the orphan instances themselves and complements @<http://hackage.haskell.org/package/base-compat base-compat>@.
    See the README for what instances are covered: <https://github.com/haskell-compat/base-orphans#readme>. See also the <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered> section.
category: Compatibility
abi: 9d1eb5b04157e6a04f0c8e24c12b6390
exposed: True
exposed-modules:
    Data.Orphans
hidden-modules: Data.Orphans.Prelude
import-dirs: /usr/lib/ghc-8.4.3/site-local/base-orphans-0.8
library-dirs: /usr/lib/ghc-8.4.3/site-local/base-orphans-0.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/base-orphans-0.8
hs-libraries: HSbase-orphans-0.8-IMe9IACIp8aFSEynTCteC2
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
haddock-interfaces: /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock
haddock-html: /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-orphans-0.8-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-base-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-orphans
version: 0.8
id: base-orphans-0.8-5p9EcoYpOm2IhNppJTpsuH
key: base-orphans-0.8-5p9EcoYpOm2IhNppJTpsuH
license: MIT
copyright: (c) 2012-2017 Simon Hengel,
           (c) 2014-2017 João Cristóvão,
           (c) 2015-2017 Ryan Scott
maintainer: Simon Hengel <sol@typeful.net>,
            João Cristóvão <jmacristovao@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
author: Simon Hengel <sol@typeful.net>,
        João Cristóvão <jmacristovao@gmail.com>,
        Ryan Scott <ryan.gl.scott@gmail.com>
homepage: https://github.com/haskell-compat/base-orphans#readme
synopsis: Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in later versions of @base@ to a wider (older) range of compilers. @base-orphans@ does not export anything except the orphan instances themselves and complements @<http://hackage.haskell.org/package/base-compat base-compat>@.
    See the README for what instances are covered: <https://github.com/haskell-compat/base-orphans#readme>. See also the <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered> section.
category: Compatibility
abi: 5b8cc7db36ae6634296f09a6f0804fa4
exposed: True
exposed-modules:
    Data.Orphans
hidden-modules: Data.Orphans.Prelude
import-dirs: /usr/lib/ghc-8.4.3/site-local/base-orphans-0.8
library-dirs: /usr/lib/ghc-8.4.3/site-local/base-orphans-0.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/base-orphans-0.8
hs-libraries: HSbase-orphans-0.8-5p9EcoYpOm2IhNppJTpsuH
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
haddock-interfaces: /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock
haddock-html: /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
